# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "0.9.2.4"
FULL_VERSION = "0.9.2.4.1.0"

ARS_VERSION = "4.12.5.243"
FORGE_VERSION = "47.3.6"
FORGE_VERSION_RANGE = "[47,)"
GECKO_VERSION = "4.4.4"
HEXCASTING_VERSION = "0.11.2-pre-702"
LOADER_VERSION_RANGE = "[47,)"
MAPPING_CHANNEL = "official"
MAPPING_VERSION = "1.20.1"
MINECRAFT_VERSION = "1.20.1"
MINECRAFT_VERSION_RANGE = "[1.20.1,1.21)"
MOD_AUTHORS = "YukkuriC"
MOD_DESCRIPTION = "Link Ars Nouveau mana to Hex Casting media"
MOD_GROUP_ID = "yukkuric"
MOD_ID = "hex_ars_link"
MOD_LICENSE = "MIT"
MOD_NAME = "Hex-Ars Linker"
MOD_VERSION = "DYNAMIC"
MOD_VERSION_BASE = "0.9.2.4"
ORG_GRADLE_DAEMON = "false"
ORG_GRADLE_JVMARGS = "-Xmx3G"
PATCHOULI_VERSION = "80-FORGE"



# type: ignore
from importlib.resources import Package
from typing_extensions import override

from hexdoc.plugin import (
    HookReturn,
    ModPlugin,
    ModPluginImpl,
    ModPluginWithBook,
    hookimpl,
)

import hexdoc_hex_ars_link

from .__gradle_version__ import FULL_VERSION, GRADLE_VERSION
from .__version__ import PY_VERSION


class HexArsLinkerPlugin(ModPluginImpl):
    @staticmethod
    @hookimpl
    def hexdoc_mod_plugin(branch: str) -> ModPlugin:
        HexArsLinkerPlugin.disable_custom_pages()
        return HexArsLinkerModPlugin(branch=branch)

    @staticmethod
    def disable_custom_pages():
        from hexdoc.patchouli import Entry

        @classmethod
        def wrap_load(cls, resource_dir, id, data, context):
            data['pages'] = list(
                filter(
                    (
                        lambda p: isinstance(p, str)
                        or not p['type'].startswith('hexcasting:hex_ars_link')
                    ),
                    data['pages'],
                )
            )
            return Entry._load_original(resource_dir, id, data, context)

        Entry._load_original = Entry.load
        Entry.load = wrap_load


class HexArsLinkerModPlugin(ModPluginWithBook):
    @property
    @override
    def modid(self) -> str:
        return "hex_ars_link"

    @property
    @override
    def full_version(self) -> str:
        return FULL_VERSION

    @property
    @override
    def mod_version(self) -> str:
        return GRADLE_VERSION

    @property
    @override
    def plugin_version(self) -> str:
        return PY_VERSION

    @override
    def resource_dirs(self) -> HookReturn[Package]:
        # lazy import because generated may not exist when this file is loaded
        # eg. when generating the contents of generated
        # so we only want to import it if we actually need it
        from ._export import generated

        return generated

    @override
    def jinja_template_root(self) -> tuple[Package, str]:
        return hexdoc_hex_ars_link, "_templates"
